==> haskell-typed-process-0.2.6.0-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-typed-process.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: typed-process
version: 0.2.6.0
id: typed-process-0.2.6.0-KcmVadAwrEfF2ZCRvCEUEk
key: typed-process-0.2.6.0-KcmVadAwrEfF2ZCRvCEUEk
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://haskell-lang.org/library/typed-process
synopsis: Run external processes, with strong typing of streams
description:
    Please see the tutorial at <https://haskell-lang.org/library/typed-process>
category: System
abi: 1e358297ae184cc96079a30140b33aee
exposed: True
exposed-modules:
    System.Process.Typed System.Process.Typed.Internal
hidden-modules: Paths_typed_process
import-dirs: /usr/lib/ghc-8.6.5/site-local/typed-process-0.2.6.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/typed-process-0.2.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/typed-process-0.2.6.0
hs-libraries: HStyped-process-0.2.6.0-KcmVadAwrEfF2ZCRvCEUEk
depends:
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    bytestring-0.10.8.2 process-1.6.5.0 stm-2.5.0.0
    transformers-0.5.6.2 unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
haddock-interfaces: /usr/share/doc/haskell-typed-process/html/typed-process.haddock
haddock-html: /usr/share/doc/haskell-typed-process/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-typed-process-0.2.6.0-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-typed-process.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: typed-process
version: 0.2.6.0
id: typed-process-0.2.6.0-JO3mmyY2u6LLSTLlN1UANK
key: typed-process-0.2.6.0-JO3mmyY2u6LLSTLlN1UANK
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://haskell-lang.org/library/typed-process
synopsis: Run external processes, with strong typing of streams
description:
    Please see the tutorial at <https://haskell-lang.org/library/typed-process>
category: System
abi: 03c6878b1b19e2f1d1d118a08da34d32
exposed: True
exposed-modules:
    System.Process.Typed System.Process.Typed.Internal
hidden-modules: Paths_typed_process
import-dirs: /usr/lib/ghc-8.6.5/site-local/typed-process-0.2.6.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/typed-process-0.2.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/typed-process-0.2.6.0
hs-libraries: HStyped-process-0.2.6.0-JO3mmyY2u6LLSTLlN1UANK
depends:
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    bytestring-0.10.8.2 process-1.6.5.0 stm-2.5.0.0
    transformers-0.5.6.2 unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
haddock-interfaces: /usr/share/doc/haskell-typed-process/html/typed-process.haddock
haddock-html: /usr/share/doc/haskell-typed-process/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
